@@ -1,4 +1,3 @@
-context("print, summary")
 glicko <- glicko_run(rank | id ~ player(rider), data = gpheats[1:32, ])
 dbl <- dbl_run(rank | id ~ player(rider), data = gpheats[1:32, ])
 
@@ -19,18 +18,7 @@ testthat::test_that("Plot layers match", {
   )
 })
 
-testthat::test_that("Plot layers match expectations", {
-  p <- plot(dbl)
-  testthat::expect_identical(class(p$layers[[1]]$geom), c("GeomLinerange", "Geom", "ggproto", "gg"))
-  testthat::expect_identical(class(p$layers[[2]]$geom), c("GeomPoint", "Geom", "ggproto", "gg"))
-})
-
-testthat::test_that("Scale is labelled 'r'", {
-  p <- plot(dbl)
-  testthat::expect_identical(p$labels$y, "r")
-})
-
-testthat::test_that("Scale range is NULL", {
-  p <- plot(dbl)
-  testthat::expect_null(p$scales$scales[[1]]$range$range)
+testthat::test_that("Plot output matches snapshot", {
+  vdiffr::expect_doppelganger("dbl_plot", plot(dbl))
+  vdiffr::expect_doppelganger("glicko_plot", plot(glicko))
 })
